@@ -51,7 +51,7 @@ SEXP extractFieldAsSEXP( const Rcpp::XPtr<GPB::Message>& message, const GPB::Des
 	case TYPE : \
 		return Rcpp::wrap( RepeatedFieldImporter<DATATYPE>(ref, *message, fieldDesc) ) ; \
 
-		HANDLE_REPEATED_FIELD(CPPTYPE_INT32, GPB::int32) ;
+			HANDLE_REPEATED_FIELD(CPPTYPE_INT32, GPB::int32) ;
     		HANDLE_REPEATED_FIELD(CPPTYPE_INT64, GPB::int64) ;
     		HANDLE_REPEATED_FIELD(CPPTYPE_UINT32 , GPB::uint32) ;
     		HANDLE_REPEATED_FIELD(CPPTYPE_UINT64 , GPB::uint64) ;
@@ -59,10 +59,24 @@ SEXP extractFieldAsSEXP( const Rcpp::XPtr<GPB::Message>& message, const GPB::Des
     		HANDLE_REPEATED_FIELD(CPPTYPE_FLOAT, float) ;
     		HANDLE_REPEATED_FIELD(CPPTYPE_BOOL, bool) ;
     		HANDLE_REPEATED_FIELD(CPPTYPE_ENUM, enum_field ) ;
-    		HANDLE_REPEATED_FIELD(CPPTYPE_STRING, std::string ) ;
     		HANDLE_REPEATED_FIELD(CPPTYPE_MESSAGE, message_field ) ;
 #undef HANDLE_REPEATED_FIELD
 
+		case CPPTYPE_STRING:
+			if (fieldDesc->type() == TYPE_STRING) {
+				return Rcpp::wrap( RepeatedFieldImporter<std::string>(ref, *message, fieldDesc) ) ;
+			} else if (fieldDesc->type() == TYPE_BYTES) {
+				int field_size = ref->FieldSize( *message, fieldDesc ) ;
+				Rcpp::List res(field_size);
+				for (int i=0; i<field_size; i++) {
+					std::string s = ref->GetRepeatedString(*message, fieldDesc, i);
+					res[i] =  Rcpp::wrap(std::vector<Rbyte>(s.begin(), s.end()));
+				}
+				return res;
+			} else {
+				throwException( "unknown field type with CPP_TYPE STRING", "ConversionException" ) ;
+			}
+
     	}
     	
     } else {
@@ -81,14 +95,22 @@ SEXP extractFieldAsSEXP( const Rcpp::XPtr<GPB::Message>& message, const GPB::Des
 		HANDLE_SINGLE_FIELD( CPPTYPE_DOUBLE, Double );
 		HANDLE_SINGLE_FIELD( CPPTYPE_FLOAT, Float );
 		HANDLE_SINGLE_FIELD( CPPTYPE_BOOL, Bool );
-		HANDLE_SINGLE_FIELD( CPPTYPE_STRING, String );
 #undef HANDLE_SINGLE_FIELD
 
+		case CPPTYPE_STRING:
+			if (fieldDesc->type() == TYPE_STRING) {
+				return Rcpp::wrap( ref->GetString(*message, fieldDesc) );
+			} else if (fieldDesc->type() == TYPE_BYTES) {
+				std::string s = ref->GetString(*message, fieldDesc);
+				return Rcpp::wrap(std::vector<Rbyte>(s.begin(), s.end()));
+			} else {
+				throwException( "unknown field type with CPP_TYPE STRING", "ConversionException" ) ;			   
+			}
 		case CPPTYPE_ENUM : 
-    			return Rcpp::wrap( ref->GetEnum( *message, fieldDesc )->number() ) ;
+			return Rcpp::wrap( ref->GetEnum( *message, fieldDesc )->number() ) ;
     		
-    		case CPPTYPE_MESSAGE:
-    			return S4_Message( CLONE( &ref->GetMessage( *message, fieldDesc ) ) ) ;
+   		case CPPTYPE_MESSAGE:
+			return S4_Message( CLONE( &ref->GetMessage( *message, fieldDesc ) ) ) ;
     			break ;
     	}
     }
